@@ -9,6 +9,7 @@ import fileinput
 
 # import pyenchant  # spell check
 import re
+import sys
 import textwrap
 
 import pyparsing as pp
@@ -62,8 +63,6 @@ class ConventionalCommit:
     footers : [dict]
         An array of footer dicts, which are identical to the breaking
         dicts, without a "flag" field.
-    options : object
-        A Config() object containing current configuration options.
     exc : object
         ParseException raised during parsing, or ``None``.
     """
@@ -232,11 +231,15 @@ class ConventionalCommitRunner(ConventionalCommit):
         configuration, defaulting to ``STDIN``.
         """
         commit = ""
-        with fileinput.FileInput(files=(self.options.commit), mode="r") as input:
-            for line in input:
-                commit += line
+        try:
+            with fileinput.FileInput(files=(self.options.commit), mode="r") as input:
+                for line in input:
+                    commit += line
 
-        self.raw = commit
+            self.raw = commit
+        except FileNotFoundError as error:
+            print(f"{error.strerror}: {error.filename}")
+            raise
 
     def wrap(self):
         """Wrap a commit body to a given length."""
@@ -433,7 +436,7 @@ class ConventionalCommitRunner(ConventionalCommit):
         return
 
 
-def main():
+def main(argv=None):
     """Run the default program.
 
     Creates a ``ConventionalCommitRunner()``; loads the configuration
@@ -442,12 +445,13 @@ def main():
     failure.
     """
     runner = ConventionalCommitRunner()
-    runner.options.load()
+    runner.options.load(argv)
+    runner.options.validate()
     runner.get()
     runner.clean()
     runner.parse()
 
     if runner.exc:
-        exit(1)
+        sys.exit(1)
     else:
-        exit(0)
+        sys.exit(0)
